from setuptools import find_packages, setup

setup(name='hiphip',
      description='',
      version='1.0.0-alpha.6',
      url='https://github.com/nikitanovosibirsk/hiphip',
      author='Nikita Tsvetkov',
      author_email='nikitanovosibirsk@yandex.com',
      license='MIT',
      packages=find_packages())
